@@ -63,28 +63,32 @@ class SwidgetWebsocket:
 
         try:
             headers = {'Connection': 'Upgrade'}
-            async with self.session.ws_connect(self.uri, headers=headers, verify_ssl=False) as self.ws_client:
-                _LOGGER.error("AIOHTTP websocket connected")
-                self.state = STATE_CONNECTED
-                self.failed_attempts = 0
-                self.send_str(json.dumps({"type": "summary", "request_id": "1"}))
-                self.send_str(json.dumps({"type": "state", "request_id": "2"}))
-                async for message in self.ws_client:
-                    _LOGGER.error(f'AIOHTTP websocket message {message.type}')
-                    if self.state == STATE_STOPPED:
-                        break
+            async with self.session.ws_connect(self.uri, headers=headers, verify_ssl=False, heartbeat=30) as self.ws_client:
+                try:
+                    _LOGGER.error("AIOHTTP websocket connected")
+                    self.state = STATE_CONNECTED
+                    self.failed_attempts = 0
+                    self.send_str(json.dumps({"type": "summary", "request_id": "1"}))
+                    self.send_str(json.dumps({"type": "state", "request_id": "2"}))
+                    async for message in self.ws_client:
+                        _LOGGER.error(f'AIOHTTP websocket message {message.type}')
+                        if self.state == STATE_STOPPED:
+                            break
 
-                    if message.type == aiohttp.WSMsgType.TEXT:
-                        msg = message.json()
-                        await self.callback(msg)
+                        if message.type == aiohttp.WSMsgType.TEXT:
+                            msg = message.json()
+                            await self.callback(msg)
 
-                    elif message.type == aiohttp.WSMsgType.CLOSED:
-                        _LOGGER.warning("AIOHTTP websocket connection closed")
-                        break
+                        elif message.type == aiohttp.WSMsgType.CLOSED:
+                            _LOGGER.warning("AIOHTTP websocket connection closed")
+                            break
+
+                        elif message.type == aiohttp.WSMsgType.ERROR:
+                            _LOGGER.error(f"AIOHTTP websocket error. Message-type: {message.type} {message}")
+                            break
+                except ConnectionTimeoutError as e:
+                    _LOGGER.error('Error connecting.')
 
-                    elif message.type == aiohttp.WSMsgType.ERROR:
-                        _LOGGER.error(f"AIOHTTP websocket error. Message-type: {message.type} {message}")
-                        break
 
         except aiohttp.ClientResponseError as error:
             _LOGGER.error(f'AIOHTTP ClientResponseError')
